""" This module converts PDFs to Text. """


class Convertor:
    """ Description for Convertor class"""

    def convert(self, path):
        """
        Simple Function for converting PDFs to text.

        Parameters:
        path (str): a path to the pdf file

        Returns:
        str: text equivalent of the pdf file
        """

        print("PDF2TEXT")
